@@ -1,9 +1,9 @@
 use strict;
 use warnings;
 no warnings 'once';
-package Net::Continental::Zone;
+package Net::Continental::Zone 0.017;
 # ABSTRACT: a zone of IP space
-$Net::Continental::Zone::VERSION = '0.016';
+
 use Locale::Codes::Country 3.29 ();
 use Net::Domain::TLD ();
 
@@ -91,7 +91,17 @@ Net::Continental::Zone - a zone of IP space
 
 =head1 VERSION
 
-version 0.016
+version 0.017
+
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
 
 =head1 METHODS
 
@@ -132,7 +142,7 @@ This returns true if the zone code is also a country code TLD.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
